@@ -1,6 +1,6 @@
 import os
 import socket
-from .lib.utils import Color
+from .lib.utils import Color, prefix_text_formatting
 
 
 class Hostname(Color):
@@ -10,7 +10,7 @@ class Hostname(Color):
         self.hostname_enable = self.config["hostname"]["enable"]
         self.hostname_color = self.config["hostname"]["color"]
         self.hostname_prefix_color = self.config["hostname"]["prefix"]["color"]
-        self.hostname_prefix_text = self.config["hostname"]["prefix"]["text"]
+        self.hostname_prefix_text = prefix_text_formatting(self.config["hostname"]["prefix"]["text"])
 
     def __str__(self, prefix="", space_elem=" "):
         if self.config["username"]["enable"] or "SSH_CONNECTION" in os.environ:
