@@ -1,5 +1,5 @@
 import os
-from .lib.utils import Color, separator, choice_symbol
+from .lib.utils import Color, separator, choice_symbol, prefix_text_formatting
 
 
 def get_virtualenv_name():
@@ -20,7 +20,7 @@ class Virtualenv(Color):
         self.venv_involved = config["virtualenv"]["involved"]
         self.venv_color = config["virtualenv"]["color"]
         self.venv_prefix_color = config["virtualenv"]["prefix"]["color"]
-        self.venv_prefix_text = config["virtualenv"]["prefix"]["text"]
+        self.venv_prefix_text = prefix_text_formatting(config["virtualenv"]["prefix"]["text"])
         self.venv_name_enable = config["virtualenv"]["name"]["normal"]["enable"]
         self.venv_name_text = config["virtualenv"]["name"]["text"]
 
